package bluetoothconnect;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.ListView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.example.bluetooth.le.R;
import com.example.bluetooth.le.Util;
import com.hprt.m300lib.HPRTHelper;
import com.hprt.m300lib.HPRTHelper.onDisconnect;
import com.hprt.m300lib.HidConncetUtil;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

public class MainActivity extends Activity {
    private BluetoothAdapter mBluetoothAdapter;
    private HidConncetUtil mHidConncetUtil;
    private BlueBroadcastReceiver mBlueBroadcastReceiver;
    private MyBluetoothAdapter mMyBluetoothAdapter;
    private ListView mListView;
	private HPRTHelper mHelper;
	private Context mContext;
	private TextView tv_nodevice;
	private ProgressBar progress_scan;
	private List<BluetoothDevice> mList = new ArrayList<BluetoothDevice>();
    private String[] BLUE_PERMISSIONS={android.Manifest.permission.ACCESS_COARSE_LOCATION};
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mContext = getApplicationContext();
        setTitle(Util.packageName(mContext));
        initview();
        initBlue();
//        setScan();
    }

    private void initview() {
        mListView = (ListView) findViewById(R.id.listview);
        tv_nodevice = (TextView) findViewById(R.id.tv_nodevice);
        progress_scan = (ProgressBar) findViewById(R.id.progress_scan);
        Button search = (Button) findViewById(R.id.search);
        search.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //扫描蓝牙设备
//                if (!mBluetoothAdapter.isDiscovering()) {
                setScan();
            }
        });
    }

    private void setScan() {
        Util.checkBlueboothPermission(MainActivity.this, android.Manifest.permission.ACCESS_COARSE_LOCATION, BLUE_PERMISSIONS,  new Util.Callback() {

            @Override
            public void permit() {
                progress_scan.setVisibility(View.VISIBLE);
//                mList.clear();
//                mMyBluetoothAdapter.addData(mList);
//                mMyBluetoothAdapter.notifyDataSetChanged();
                mBluetoothAdapter.startDiscovery();
            }

        });
    }

    private void initPair(){
        if (mBluetoothAdapter == null) {
            Toast.makeText(this,getString(R.string.bluetooth_no_support),Toast.LENGTH_SHORT).show();
            //不支持蓝牙
            return;
        }
        mList.clear();
        //得到已经配对的列表
        Set<BluetoothDevice> mSet = mBluetoothAdapter.getBondedDevices();
        final Iterator mIterator = mSet.iterator();
        while (mIterator.hasNext()) {
            BluetoothDevice mBluetoothDevice = (BluetoothDevice) mIterator
                    .next();
            if(mMyBluetoothAdapter==null){
                mMyBluetoothAdapter = new MyBluetoothAdapter(MainActivity.this);
                mListView.setAdapter(mMyBluetoothAdapter);
            }
            mList.add(mBluetoothDevice);
        }
        if (mList.size()==0) {
        	tv_nodevice.setVisibility(View.VISIBLE);
		}else {
			mMyBluetoothAdapter.addData(mList);
	        mMyBluetoothAdapter.notifyDataSetChanged();
			tv_nodevice.setVisibility(View.GONE);
		}
    }

    private void initBlue() {
        //初始化广播接收
        mBlueBroadcastReceiver = new BlueBroadcastReceiver();
        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if (mBluetoothAdapter == null) {
            Toast.makeText(this,getString(R.string.bluetooth_no_support),Toast.LENGTH_SHORT).show();
            //不支持蓝牙
            return;
        }
        //如果没有打开蓝牙
        if (!mBluetoothAdapter.isEnabled()) {
            mBluetoothAdapter.enable();
        }
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
            this.mHidConncetUtil = new HidConncetUtil(this);
        }
        initPair();
        mHelper = HPRTHelper.getHPRTHelper(MainActivity.this);
        registerReceiver();
        if(mMyBluetoothAdapter==null){
            mMyBluetoothAdapter = new MyBluetoothAdapter(MainActivity.this);
            mListView.setAdapter(mMyBluetoothAdapter);
        }
    }


    @Override
    protected void onResume() {
        super.onResume();
    }

    @Override
    protected void onPause() {
        super.onPause();
    }


    public void registerReceiver() {
        IntentFilter localIntentFilter = new IntentFilter();
        localIntentFilter.addAction(BluetoothDevice.ACTION_FOUND);
        localIntentFilter.addAction(BluetoothDevice.ACTION_BOND_STATE_CHANGED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_CONNECTED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECT_REQUESTED);
        localIntentFilter.addAction(BluetoothDevice.ACTION_ACL_DISCONNECTED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_STATE_CHANGED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_DISCOVERY_STARTED);
        localIntentFilter.addAction(BluetoothAdapter.ACTION_DISCOVERY_FINISHED);
        this.registerReceiver(mBlueBroadcastReceiver, localIntentFilter);
    }

    private class BlueBroadcastReceiver  extends BroadcastReceiver{

        @Override
        public void onReceive(Context context, Intent intent) {
            String str = intent.getAction();
            if (BluetoothDevice.ACTION_FOUND.equals(str)) {
            	Log.d("Print:", "onReceive" + str);
            	//通过广播接收到了BluetoothDevice
            	final BluetoothDevice localBluetoothDevice = (BluetoothDevice) intent
            			.getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
            	if (localBluetoothDevice != null) {
            		if(mMyBluetoothAdapter==null){
            			mMyBluetoothAdapter = new MyBluetoothAdapter(MainActivity.this);
            			mListView.setAdapter(mMyBluetoothAdapter);
            		}
                    boolean isOK=true;
                    for (int i = 0; i < mList.size(); i++) {
                        if (mList.get(i).getAddress().equals(localBluetoothDevice.getAddress()))
                            isOK=false;
                    }
                    if (isOK){
                        if (!TextUtils.isEmpty(localBluetoothDevice.getName())){
                            if(localBluetoothDevice.getName().contains("HPRT")){
                                mList.add(localBluetoothDevice);
                                mMyBluetoothAdapter.addData(mList);
                                mMyBluetoothAdapter.notifyDataSetChanged();
                            }
                        }
                    }
            	}
			}if(BluetoothAdapter.ACTION_DISCOVERY_FINISHED.equals(str)){
                progress_scan.setVisibility(View.GONE);
            }
        }
    }
    @Override
    protected void onStop() {
    	// TODO Auto-generated method stub
    	super.onStop();
    }
    @Override
    protected void onDestroy() {
    	// TODO Auto-generated method stub
    	super.onDestroy();
//    	unregisterReceiver(mBlueBroadcastReceiver);
        this.unregisterReceiver(mBlueBroadcastReceiver);
    	if (mHelper!=null) {
    		mHelper.disconnect(new onDisconnect() {
				
				@Override
				public void succeed() {
					// TODO Auto-generated method stub
					
				}
			});
		}
    }
}
