package bluetoothconnect;

import android.bluetooth.BluetoothDevice;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.example.bluetooth.le.MenuActivity;
import com.example.bluetooth.le.R;
import com.hprt.m300lib.HPRTHelper;
import com.hprt.m300lib.HPRTHelper.onConnect;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by liushen on 2016/5/31.
 */
public class MyBluetoothAdapter extends BaseAdapter {
    private List<BluetoothDevice> mList = new ArrayList<BluetoothDevice>();
    private Context mContext;
	private HPRTHelper mHprt;
    public MyBluetoothAdapter(List<BluetoothDevice> mList, Context mContext) {
        this.mList = mList;
        this.mContext = mContext;
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
            mHprt = HPRTHelper.getHPRTHelper(mContext);
        }
    }
    public MyBluetoothAdapter(Context mContext) {
        this.mContext = mContext;
        //4.0以上才支持HID模式
        if (Build.VERSION.SDK_INT >= 14) {
        	mHprt = HPRTHelper.getHPRTHelper(mContext);
        }
    }

    @Override
    public int getCount() {
        return mList.size();
    }

    @Override
    public Object getItem(int position) {
        return mList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    public void addData(List<BluetoothDevice> bluetoothDevice){
    	mList.clear();
        mList.addAll(bluetoothDevice);
    }
    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder = null;
        if(convertView==null){
            convertView = View.inflate(mContext,R.layout.blue_list_item,null);
            viewHolder = new ViewHolder(convertView);
            convertView.setTag(viewHolder);
        }else{
            viewHolder = (ViewHolder) convertView.getTag();
        }
        initData(position,viewHolder);
        return convertView;
    }

    private void initData(int position,ViewHolder viewHolder) {
        final BluetoothDevice bluetoothDevice = mList.get(position);
        viewHolder.bluehandlename.setText(bluetoothDevice.getName());
        viewHolder.bluehandlebond.setText(bluetoothDevice.getAddress());
        viewHolder.connect.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
            	mHprt.setDevice(bluetoothDevice);
            	mHprt.buleconnect(mContext,new onConnect() {
					@Override
					public void succeed() {
						mContext.startActivity(new Intent(mContext, MenuActivity.class));
					}
					
					@Override
					public void failure() {
						Toast.makeText(mContext, mContext.getString(R.string.bluetooth_connection_failed), Toast.LENGTH_SHORT).show();
					}
				});
            }
        });
    }

    /**
     * 判断是否配对并设置配置状态
     * @param bluetoothDevice
     */
    private void isBonded(BluetoothDevice bluetoothDevice,ViewHolder viewHolder){
        int state =  bluetoothDevice.getBondState();
        switch (state) {
            case BluetoothDevice.BOND_NONE:
                viewHolder.bluehandlebond.setText("未配对");
                break;
            case BluetoothDevice.BOND_BONDING:
                viewHolder.bluehandlebond.setText("配对中...");
                break;
            case BluetoothDevice.BOND_BONDED:
                viewHolder.bluehandlebond.setText("已配对");
                break;
        }
    }


    public class ViewHolder {
        public final TextView bluehandlename;
        public final TextView bluehandlebond;
        public final Button connect;
        public final View root;

        public ViewHolder(View root) {
            bluehandlename = (TextView) root.findViewById(R.id.blue_handle_name);
            bluehandlebond = (TextView) root.findViewById(R.id.blue_handle_bond);
            connect = (Button) root.findViewById(R.id.connect);
            this.root = root;
        }
    }
}
