package com.example.bluetooth.le;


import android.app.Activity;
import android.app.AlertDialog.Builder;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.TextView;

import com.hprt.m300lib.HPRTHelper;
import com.hprt.m300lib.HPRTHelper.onDeviceName;
import com.hprt.m300lib.HPRTHelper.onDisconnect;
import com.hprt.m300lib.HPRTHelper.onElectricity;
import com.hprt.m300lib.HPRTHelper.onReaddeviceversion;
import com.hprt.m300lib.HPRTHelper.onWorkModel;

public class MenuActivity extends Activity implements OnClickListener{
	private HPRTHelper mHelper;
	private TextView tv_version;
	private TextView tv_electricity;
	private TextView tv_work_model;
	private Context mContext;
	private int GATT=1;
	private int HID=2;
	private boolean isgetWork=false;
	private int WORK_MODEL=0;
	private TextView tv_voltage;
	private TextView tv_device_name;
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_menu);
		mContext = getApplicationContext();
		init();
	}

	private void init() {
		tv_version = (TextView) findViewById(R.id.tv_version);
		tv_version.setOnClickListener(this);
		tv_electricity = (TextView) findViewById(R.id.tv_electricity);
		tv_electricity.setOnClickListener(this);
		tv_work_model = (TextView) findViewById(R.id.tv_work_model);
		tv_work_model.setOnClickListener(this);
		tv_voltage = (TextView) findViewById(R.id.tv_voltage);
		tv_voltage.setOnClickListener(this);
		tv_device_name = (TextView) findViewById(R.id.tv_devicename);
		tv_device_name.setOnClickListener(this);
		mHelper = HPRTHelper.getHPRTHelper(MenuActivity.this);
//		mHelper.init();
		initData();
	}

	private void initData() {
		readversion();
		getDeviceName();
		getPower();
		getWorkModel();
	}
	//获取设备名称
	private void getDeviceName(){
		mHelper.getDeviceName(new onDeviceName() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				tv_device_name.setText(getString(R.string.menu_device_name)+Util.byteASCIIstr(data));
			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_device_name.setText(getString(R.string.menu_device_name)+getString(R.string.menu_click_to_get));
			}
		});
	}
	
	//获取版本号
	private void readversion(){
		mHelper.setReaddeviceversion(new onReaddeviceversion() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				tv_version.setText(getString(R.string.menu_version_number)+data[data.length-1]+data[data.length-2]);
			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_version.setText(getString(R.string.menu_version_number)+getString(R.string.menu_click_to_get));
			}
		});
	}
	private void getPower(){
		mHelper.getElectricity(new onElectricity() {
			
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				tv_electricity.setText(getString(R.string.menu_electricity)+data[4]+"%");
				String parseHex =HPRTHelper.bytetohex(data[2])+HPRTHelper.bytetohex(data[3]);
				tv_voltage.setText(getString(R.string.menu_voltage)+Integer.parseInt(parseHex.trim(),16)+"mV");
			}
			
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_electricity.setText(getString(R.string.menu_electricity)+getString(R.string.menu_click_to_get));
				tv_voltage.setText(getString(R.string.menu_voltage)+getString(R.string.menu_click_to_get));
			}
		});
	}
	private void getWorkModel(){
		mHelper.getWorkModel(new onWorkModel() {
			@Override
			public void succeed(byte[] data) {
				// TODO Auto-generated method stub
				if (data[2]==1) {
					tv_work_model.setText(getString(R.string.menu_working_mode)+"GATT");
					WORK_MODEL=GATT;
					isgetWork=true;
				}else if(data[2]==2){
					tv_work_model.setText(getString(R.string.menu_working_mode)+"HID");
					WORK_MODEL=HID;
					isgetWork=true;
				}else{
					tv_work_model.setText(getString(R.string.menu_working_mode)+getString(R.string.menu_click_to_get));
					isgetWork=false;
				}
			}
			@Override
			public void failure() {
				// TODO Auto-generated method stub
				tv_work_model.setText(getString(R.string.menu_working_mode)+getString(R.string.menu_click_to_get));
				isgetWork=false;
			}
		});
	}
	public void setting(View view){
		startActivity(new Intent(MenuActivity.this, SettingActivity.class));
	}
	public void workmodel(View view){
		if (isgetWork) {
			View contentView = LayoutInflater.from(mContext).inflate(
					R.layout.dialog_work_model, null);
			Builder builder = Util.DialogView(MenuActivity.this, contentView);
			final RadioGroup rg_work_model = (RadioGroup) contentView.findViewById(R.id.rg_work_model);
			switch (WORK_MODEL) {
			case 1:
				rg_work_model.check(R.id.rb_workmodel_gatt);
				break;
			case 2:
				rg_work_model.check(R.id.rb_workmodel_hid);
				break;
			default:
				break;
			}
			builder.setNegativeButton(R.string.menu_sure, new DialogInterface.OnClickListener() {
				
				@Override
				public void onClick(DialogInterface dialog, int which) {
					// TODO Auto-generated method stub
					switch (rg_work_model.getCheckedRadioButtonId()) {
					case R.id.rb_workmodel_gatt:
						if(mHelper.setWorkModel(GATT)){
							Util.ToastMessage(mContext, getString(R.string.menu_set_succeed));
							finish();
						}else{
							Util.ToastMessage(mContext, getString(R.string.menu_set_failed));
						}
						break;
					case R.id.rb_workmodel_hid:
						if(mHelper.setWorkModel(HID)){
							Util.ToastMessage(mContext,getString(R.string.menu_set_succeed));
							finish();
						}else{
							Util.ToastMessage(mContext,  getString(R.string.menu_set_failed));
						}
						break;

					default:
						break;
					}
				}
			});
			builder.setNeutralButton(getString(R.string.menu_cancel), null);
			builder.show();
		}else {
			Util.ToastMessage(mContext, getString(R.string.menu_failed_worked));
		}
	}
	public void scandata(View view){
		startActivity(new Intent(this, ScanDataActivity.class));
	}
	public void functions(View view){
		startActivity(new Intent(this, FunctionsActivity.class));
	}
	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		if (mHelper!=null) {
    		mHelper.disconnect(new onDisconnect() {
				
				@Override
				public void succeed() {
					// TODO Auto-generated method stub
				}
			});
		}
	}

	@Override
	public void onClick(View v) {
		// TODO Auto-generated method stub
		switch (v.getId()) {
		case R.id.tv_version:
			if ((getString(R.string.menu_version_number)+getString(R.string.menu_click_to_get)).equals(tv_version.getText())) {
				readversion();
			}
			break;
		case R.id.tv_electricity:
			if ((getString(R.string.menu_electricity)+getString(R.string.menu_click_to_get)).equals(tv_electricity.getText())) {
				getPower();
			}
			break;
		case R.id.tv_voltage:
			if ((getString(R.string.menu_voltage)+getString(R.string.menu_click_to_get)).equals(tv_voltage.getText())) {
				getPower();
			}
			break;
		case R.id.tv_work_model:
			if ((getString(R.string.menu_working_mode)+getString(R.string.menu_click_to_get)).equals(tv_work_model.getText())) {
				getWorkModel();
			}
			break;
		case R.id.tv_devicename:
			if ((getString(R.string.menu_device_name)+getString(R.string.menu_click_to_get)).equals(tv_device_name.getText())) {
				getDeviceName();
			}
			break;

		default:
			break;
		}
	}
	public void deviceName(View view){
		View contentView = LayoutInflater.from(mContext).inflate(
				R.layout.dialog_device_name, null);
		Builder builder = Util.DialogView(MenuActivity.this, contentView);
		final EditText ed_device_name = (EditText) contentView.findViewById(R.id.ed_device_name);
		builder.setPositiveButton(R.string.menu_sure, new DialogInterface.OnClickListener() {
			
			@Override
			public void onClick(DialogInterface dialog, int which) {
				// TODO Auto-generated method stub
				if(mHelper.setDeviceName(ed_device_name.getText().toString())){
					initData();
					Util.ToastMessage(mContext, getString(R.string.menu_set_succeed));
				}else{
					Util.ToastMessage(mContext, getString(R.string.menu_set_failed));
				}
			}
		});
		builder.setNegativeButton(R.string.menu_cancel, null);
		builder.show();
	}
	public void Temporarily(View view){
		startActivity(new Intent(MenuActivity.this, TemporarilyActivity.class));
	}
}
